summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/groupwise/libgroupwise/gwfield.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/groupwise/libgroupwise/gwfield.h')
-rw-r--r--kopete/protocols/groupwise/libgroupwise/gwfield.h50
1 files changed, 25 insertions, 25 deletions
diff --git a/kopete/protocols/groupwise/libgroupwise/gwfield.h b/kopete/protocols/groupwise/libgroupwise/gwfield.h
index 9362b5ad..0117b3e5 100644
--- a/kopete/protocols/groupwise/libgroupwise/gwfield.h
+++ b/kopete/protocols/groupwise/libgroupwise/gwfield.h
@@ -146,10 +146,10 @@
#define NMFIELD_MAX_STR_LENGTH 32768
-#include <qglobal.h>
-#include <qobject.h>
-#include <qvariant.h>
-#include <qvaluelist.h>
+#include <tqglobal.h>
+#include <tqobject.h>
+#include <tqvariant.h>
+#include <tqvaluelist.h>
/**
* Fields are typed units of information interchanged between the groupwise server and its clients.
@@ -167,26 +167,26 @@ namespace Field
{
public:
FieldBase() {}
- FieldBase( QCString tag, Q_UINT8 method, Q_UINT8 flags, Q_UINT8 type );
+ FieldBase( TQCString tag, Q_UINT8 method, Q_UINT8 flags, Q_UINT8 type );
virtual ~FieldBase() {}
- QCString tag() const;
+ TQCString tag() const;
Q_UINT8 method() const;
Q_UINT8 flags() const;
Q_UINT8 type() const;
void setFlags( const Q_UINT8 flags );
protected:
- QCString m_tag;
+ TQCString m_tag;
Q_UINT8 m_method;
Q_UINT8 m_flags;
Q_UINT8 m_type; // doch needed
};
- typedef QValueListIterator<FieldBase *> FieldListIterator;
- typedef QValueListConstIterator<FieldBase *> FieldListConstIterator;
+ typedef TQValueListIterator<FieldBase *> FieldListIterator;
+ typedef TQValueListConstIterator<FieldBase *> FieldListConstIterator;
class SingleField;
class MultiField;
- class FieldList : public QValueList<FieldBase *>
+ class FieldList : public TQValueList<FieldBase *>
{
public:
/**
@@ -194,22 +194,22 @@ namespace Field
*/
virtual ~FieldList();
/**
* Locate the first occurrence of a given field in the list. Same semantics as QValueList::find().
* @param tag The tag name of the field to search for.
* @return An iterator pointing to the first occurrence found, or end() if none was found.
*/
- FieldListIterator find( QCString tag );
+ FieldListIterator find( TQCString tag );
/**
* Locate the first occurrence of a given field in the list, starting at the supplied iterator
* @param tag The tag name of the field to search for.
* @param it An iterator within the list, to start searching from.
* @return An iterator pointing to the first occurrence found, or end() if none was found.
*/
- FieldListIterator find( FieldListIterator &it, QCString tag );
+ FieldListIterator find( FieldListIterator &it, TQCString tag );
/**
* Get the index of the first occurrence of tag, or -1 if not found
*/
- int findIndex( QCString tag );
+ int findIndex( TQCString tag );
/**
* Debug function, dumps to stdout
*/
@@ -222,11 +222,11 @@ namespace Field
* Utility functions for finding the first instance of a tag
* @return 0 if no field of the right tag and type was found.
*/
- SingleField * findSingleField( QCString tag );
- MultiField * findMultiField( QCString tag );
+ SingleField * findSingleField( TQCString tag );
+ MultiField * findMultiField( TQCString tag );
protected:
- SingleField * findSingleField( FieldListIterator &it, QCString tag );
- MultiField * findMultiField( FieldListIterator &it, QCString tag );
+ SingleField * findSingleField( FieldListIterator &it, TQCString tag );
+ MultiField * findMultiField( FieldListIterator &it, TQCString tag );
};
@@ -242,16 +242,16 @@ namespace Field
/**
* Single field constructor
*/
- SingleField( QCString tag, Q_UINT8 method, Q_UINT8 flags, Q_UINT8 type, QVariant value );
+ SingleField( TQCString tag, Q_UINT8 method, Q_UINT8 flags, Q_UINT8 type, TQVariant value );
/**
* Convenience constructor for NMFIELD_METHOD_VALID fields
*/
- SingleField( QCString tag, Q_UINT8 flags, Q_UINT8 type, QVariant value );
+ SingleField( TQCString tag, Q_UINT8 flags, Q_UINT8 type, TQVariant value );
~SingleField();
- void setValue( const QVariant v );
- QVariant value() const;
+ void setValue( const TQVariant v );
+ TQVariant value() const;
private:
- QVariant m_value;
+ TQVariant m_value;
};
/**
@@ -261,8 +261,8 @@ namespace Field
class MultiField : public FieldBase
{
public:
- MultiField( QCString tag, Q_UINT8 method, Q_UINT8 flags, Q_UINT8 type );
- MultiField( QCString tag, Q_UINT8 method, Q_UINT8 flags, Q_UINT8 type, FieldList fields );
+ MultiField( TQCString tag, Q_UINT8 method, Q_UINT8 flags, Q_UINT8 type );
+ MultiField( TQCString tag, Q_UINT8 method, Q_UINT8 flags, Q_UINT8 type, FieldList fields );
~MultiField();
FieldList fields() const;
void setFields( FieldList );
@@ -194,22 +194,22 @@ namespace Field
virtual ~FieldList();
/**
- * Locate the first occurrence of a given field in the list. Same semantics as QValueList::find().
+ * Locate the first occurrence of a given field in the list. Same semantics as TQValueList::find().
* @param tag The tag name of the field to search for.
* @return An iterator pointing to the first occurrence found, or end() if none was found.